
# ----------------------------------------------------------------------
# | Copyright  Unpublished, Rational Software Corporation. All Rights |
# | Reserved.  This software contains proprietary and confidential     |
# | information of Rational and its suppliers.  Use, disclosure or     |
# | reproduction is prohibited without the prior express written       |
# | consent of Rational Software Corporation.                          |
# ----------------------------------------------------------------------

#
# FILE: ccpb_rebase.pbl
#
# PURPOSE: This is a rebase_start postop trigger which recreates
#          PowerBuilder Libraries (PBLs) which are modified as a
#          result of a UCM rebase.
#

$debug = $ENV{'CCPB_REBASE_DEBUG'};
if ( $debug ) {
  $outfilename = "c:\\temp\\ccpb_rebase_debug.txt";
  open(OUT,">$outfilename") ||
      die "cannot create $outfilename: $!";
}

# get baseline to which stream is being rebased
$baseline = $ENV{'CLEARCASE_BASELINES'};
print OUT "baseline = $baseline\n" if $debug;

# get the user's current baseline
$fbl = `cleartool lsstream -fmt "%[found_bls]p" -cview`;
print OUT "foundation baseline = $fbl\n" if $debug;

# get vob being rebased
($bl, $vob) = split("@", $baseline);
print OUT "vob = $vob\n" if $debug;

# get PBL to recreate
@pbls = grep ( /\.pbl@@/, `cleartool diffbl -ver $fbl\@$vob $baseline` );

$pbl_count = 0;

# process each of the PBLs found
foreach $pbl ( @pbls ) {
  # strip off the ">" and "<" characters
  $pbl =~ s/<//g;
  $pbl =~ s/>//g;

  # strip off the CC extended path
  ( $pbl_path ) = split ( "@@", $pbl );

  # determine if PBL path has already been added
  $pbl_path =~ s/\\/\//g;

  if ( not grep ( /$pbl_path/, @pbl_list ) ) {
    # add unique PBL path
    @pbl_list[$pbl_count++] = $pbl_path;
    print OUT "added pbl: $pbl_path\n" if $debug;
  }
}

print OUT "\n\n\n" if $debug;

# process each PBL in our list
foreach $pbl ( @pbl_list ) {
  # construct path to POL element
  $pol_path = $pbl;
  $pol_path =~ s/.pbl/.pol/;
  $pol_path =~ s/\//\\/g;
  print OUT "run pblpopulate on: $pol_path\n" if $debug;

  # execute pblpopulate utility
  `pblpopulate.exe -silent $pol_path`;
}

close(OUT) if $debug;
